Proto Plus for Python
=====================

|pypi| |release level| |docs|

    Beautiful, Pythonic protocol buffers.

This is a wrapper around `protocol buffers`_. Protocol buffers is a
specification format for APIs, such as those inside Google.
This library provides protocol buffer message classes and objects that
largely behave like native Python types.

.. _protocol buffers: https://developers.google.com/protocol-buffers/


Documentation
-------------

`Documentation`_ is available on Read the Docs.

.. _documentation: https://proto-plus-python.readthedocs.io/en/latest/

.. |pypi| image:: https://img.shields.io/pypi/v/proto-plus.svg
   :target: https://pypi.org/project/proto-plus
.. |release level| image:: https://img.shields.io/badge/release%20level-ga-gold.svg?style&#x3D;flat
  :target: https://cloud.google.com/terms/launch-stages
.. |docs| image:: https://readthedocs.org/projects/proto-plus-python/badge/?version=latest
  :target: https://proto-plus-python.readthedocs.io/en/latest/
